==> QupZilla-2.0.2.tar.xz: QupZilla-2.0.2/src/plugins/GreaseMonkey/translations/el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.1">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>Εγκατάσταση του GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Εγκατάσταση του GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="73"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>Είστε έτοιμοι να εγκαταστήσετε αυτό το σενάριο εντολών χρηστη στο GreaseMonkey:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="86"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Θα πρέπει να εγκαθιστάτε σενάρια εντολών από πηγές που εμπιστεύεστε!&lt;b/&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="96"/>
        <source>Are you sure you want to install it?</source>
        <translation>Είστε σιγουροι ότι θέλετε να το εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="114"/>
        <source>Show source code of script</source>
        <translation>Εμφάνιση πηγαίου κώδικα για το σενάριο εντολών</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="49"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="53"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;δεν τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="83"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου εντολής</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="86"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Icon</name>
    <message>
        <location filename="../gm_icon.cpp" line="29"/>
        <source>Open GreaseMonkey settings</source>
        <translation>Άνοιγμα ρυθμίσεων του GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="206"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_manager.cpp" line="270"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="45"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>Αυτό το σενάριο χρήστη μπορεί να εγκατασταθεί με το πρόσθετο GreaseMonkey.</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="65"/>
        <source>Install</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="50"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="58"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>Σενάρια εντολών χρήστη GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Σενάρια εντολών χρήστη GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="73"/>
        <source>Double clicking script will show additional information</source>
        <translation>Με διπλό κλικ στο σενάριο θα εμφανιστούν επιπλέον πληροφορίες</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="153"/>
        <source>More scripts can be downloaded from</source>
        <translation>Μπορεί να γίνει λήψη περισσότερων σεναρίων από</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="196"/>
        <source>Open scripts directory</source>
        <translation>Άνοιγμα φακέλου σεναρίων</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="203"/>
        <source>New user script</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="90"/>
        <source>Remove script</source>
        <translation>Αφαίρεση σεναρίου</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="91"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>Είστε σίγουροι ότι θέλετε να αφαιρέσετε το &apos;%1&apos;;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="121"/>
        <source>Add script</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="121"/>
        <source>Choose name for script:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="85"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="55"/>
        <source>Version:</source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="115"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="138"/>
        <source>Namespace:</source>
        <translation>Namespace:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="155"/>
        <source>Edit in text editor</source>
        <translation>Επεξεργασία στο κειμενογράφο</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="65"/>
        <source>Start at:</source>
        <translation>Έναρξη σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="45"/>
        <source>Description:</source>
        <translation>Περιγραφή:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Runs at:</source>
        <translation>Τρέχει σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="128"/>
        <source>Does not run at:</source>
        <translation>Δεν τρέχει σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
        <source>Script Details of %1</source>
        <translation>Πληροφορίες σεναρίου %1</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.3.tar.xz: QupZilla-2.2.3/src/plugins/GreaseMonkey/translations/el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.1">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>Εγκατάσταση του GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="45"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Εγκατάσταση του GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="67"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>Είστε έτοιμοι να εγκαταστήσετε αυτό το σενάριο εντολών χρηστη στο GreaseMonkey:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="80"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Θα πρέπει να εγκαθιστάτε σενάρια εντολών από πηγές που εμπιστεύεστε!&lt;b/&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="90"/>
        <source>Are you sure you want to install it?</source>
        <translation>Είστε σιγουροι ότι θέλετε να το εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="108"/>
        <source>Show source code of script</source>
        <translation>Εμφάνιση πηγαίου κώδικα για το σενάριο εντολών</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="50"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="54"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;δεν τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="84"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου εντολής</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="87"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Icon</name>
    <message>
        <location filename="../gm_icon.cpp" line="29"/>
        <source>Open GreaseMonkey settings</source>
        <translation>Άνοιγμα ρυθμίσεων του GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="203"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_manager.cpp" line="267"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>Το «%1» είναι ήδη εγκατεστημένο</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="39"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>Αυτό το σενάριο χρήστη μπορεί να εγκατασταθεί με το πρόσθετο GreaseMonkey.</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="59"/>
        <source>Install</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="51"/>
        <source>Cannot install script</source>
        <translation>Αδυναμία εγκατάστασης σεναρίου</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="59"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>Σενάρια εντολών χρήστη GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="48"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Σενάρια εντολών χρήστη GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="70"/>
        <source>Double clicking script will show additional information</source>
        <translation>Με διπλό κλικ στο σενάριο θα εμφανιστούν επιπλέον πληροφορίες</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="150"/>
        <source>More scripts can be downloaded from</source>
        <translation>Μπορεί να γίνει λήψη περισσότερων σεναρίων από</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="193"/>
        <source>Open scripts directory</source>
        <translation>Άνοιγμα φακέλου σεναρίων</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="200"/>
        <source>New user script</source>
        <translation>Νέα μακροεντολή χρήστη</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="91"/>
        <source>Remove script</source>
        <translation>Αφαίρεση σεναρίου</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="92"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>Είστε σίγουροι ότι θέλετε να αφαιρέσετε το &apos;%1&apos;;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="122"/>
        <source>Add script</source>
        <translation>Προσθήκη μακροεντολής</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="122"/>
        <source>Choose name for script:</source>
        <translation>Επιλέξτε όνομα για την μακροεντολή:</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="85"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="55"/>
        <source>Version:</source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="115"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="138"/>
        <source>Namespace:</source>
        <translation>Namespace:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="155"/>
        <source>Edit in text editor</source>
        <translation>Επεξεργασία στο κειμενογράφο</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="65"/>
        <source>Start at:</source>
        <translation>Έναρξη σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="45"/>
        <source>Description:</source>
        <translation>Περιγραφή:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Runs at:</source>
        <translation>Τρέχει σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="128"/>
        <source>Does not run at:</source>
        <translation>Δεν τρέχει σε:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
        <source>Script Details of %1</source>
        <translation>Πληροφορίες σεναρίου %1</translation>
    </message>
</context>
</TS>
